pub enum Error {
Fatal,
Full,
}Expand description
Error indicating that the journal buffer is not available now.
Variants
Fatal
The journal is in a fatal state, caller should stop using it and drop it as soon as possible.
Full
The journal buffer is full, new entries cannot be accepted until some entries are consumed and the buffer has space.