JournalReader

Struct JournalReader 

pub struct JournalReader { /* private fields */ }
A reader for consuming settled entries from the journal.

Reader WON’T advance the shared consumed boundary until commit() is called. Entries are fetched from RocksDB into an internal buffer on each read call.

Implementations

Source

impl JournalReader

pub fn available(&self) -> usize

Returns the number of available entries that have been written but not yet consumed by this reader.

pub async fn wait_at_least(&mut self, min: usize) -> Result<(), Error>

Wait until at least min entries are available.

pub fn read(&mut self, max: usize) -> Result<&[Box<[u8]>], Error>

Read available entries from RocksDB, up to max.

Bumps the internal consumed cursor by the number of entries yielded. Caller is responsible for calling commit after processing the entries.

pub fn commit(&mut self) -> Result<(), Error>

Commit the current consumed index, persisting it to RocksDB and deleting consumed entries.