pub struct JournalReader { /* private fields */ }Expand description
A reader for consuming settled entries from the journal.
Reader WON’T advance the shared consumed boundary until commit() is
called. Entries are fetched from RocksDB into an internal buffer on each
read call.
Implementations
Sourceimpl JournalReader
impl JournalReader
Sourcepub fn available(&self) -> usize
pub fn available(&self) -> usize
Returns the number of available entries that have been written but not yet consumed by this reader.
Sourcepub async fn wait_at_least(&mut self, min: usize) -> Result<(), Error>
pub async fn wait_at_least(&mut self, min: usize) -> Result<(), Error>
Wait until at least min entries are available.